@@ -10,8 +10,8 @@ from django.core.exceptions import ValidationError
 from django.forms.utils import ErrorList
 from django.utils.html import format_html
 from django.utils.text import slugify
-from django.utils.translation import ugettext_lazy as _
-from django.utils import six
+from django.utils.translation import gettext_lazy as _
+import six
 
 from wagtail.admin.forms import WagtailAdminPageForm
 from wagtail.contrib.forms.forms import FormBuilder
